Log
GET/v1/log/levelsGET /v1/log/levels
Code samples
cURL
# You can also use wget
curl -X GET /v1/log/levels \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/log/levels
Gets the log levels for the specified date range.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| startDate | query | string(date-time) | false | none |
| endDate | query | string(date-time) | false | none |
| intervals | query | integer(int32) | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","logLevels":[{"date":"2019-08-24T14:15:22Z","level":"string","count":0}],"groupBy":"string","totalLogLevelEntriesCount":0}{
"success": true,
"code": 0,
"message": "string",
"logLevels": [
{
"date": "2019-08-24T14:15:22Z",
"level": "string",
"count": 0
}
],
"groupBy": "string",
"totalLogLevelEntriesCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetLogLevelsResponse |
Authentication: API key (x-api-key).
GET/v1/logGET /v1/log
Code samples
cURL
# You can also use wget
curl -X GET /v1/log \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/log
Gets the log entries based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| select | query | string | false | none |
| filter | query | string | false | none |
| sort | query | string | false | none |
| take | query | integer(int32) | false | none |
| skip | query | integer(int32) | false | none |
| startDate | query | string(date-time) | false | none |
| endDate | query | string(date-time) | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","logEntries":[{"id":0,"message":"string","messageTemplate":"string","level":"string","timeStamp":"2019-08-24T14:15:22Z","exception":"string","properties":"string"}],"totalLogEntriesCount":0}{
"success": true,
"code": 0,
"message": "string",
"logEntries": [
{
"id": 0,
"message": "string",
"messageTemplate": "string",
"level": "string",
"timeStamp": "2019-08-24T14:15:22Z",
"exception": "string",
"properties": "string"
}
],
"totalLogEntriesCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetLogResponse |
Authentication: API key (x-api-key).
DELETE/v1/logDELETE /v1/log
Code samples
cURL
# You can also use wget
curl -X DELETE /v1/log \
-H 'x-api-key: API_KEY'
DELETE /v1/log
Deletes a log based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| id | query | integer(int32) | false | none |
| filter | query | string | false | none |
| startDate | query | string(date-time) | false | none |
| endDate | query | string(date-time) | false | none |
| deleteAll | query | boolean | false | none |
Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | The log has been deleted successfully. Example: | |
| { | |||
| “Success”: true, | |||
| “Message”: “A total of 10 log entries have been deleted.”, | |||
| “DeletedLogCount”: 10 | |||
| } | None |
Authentication: API key (x-api-key).
Last updated on